@@ -72,11 +72,19 @@ def get_exe(prog, Debug=False, Return_Version=False):
 	if prog == 'trimmomatic':
 		list_v = ['0.36','0.37','0.38','0.39']
 		for v in list_v:
+		
+			## if using conda: there is caller	
 			exe="trimmomatic-" + v + ".jar"
 			## get paths
 			exe_path_tmp = my_which(exe)
 			if (exe_path_tmp):
 				break
+			
+			exe = "trimmomatic"
+			## get paths
+			exe_path_tmp = my_which(exe)
+			if (exe_path_tmp):
+				break
 				
 	else:
 		## get paths
@@ -302,6 +310,9 @@ def get_version(prog, path, Debug=False):
 		java_jar = java_bin + ' -jar ' + path + ' ' + args
 		cmd_output = subprocess.Popen(java_jar, shell=True, 
 									stdout=subprocess.PIPE,stderr=subprocess.PIPE).communicate()
+	
+	elif prog == 'generate_plot':
+		return("12")
 	else:
 		cmd = path + ' ' + args
 		cmd_output = subprocess.Popen(cmd, shell=True, 
