@@ -1,8 +1,8 @@
 __all__ = [
+    'assembly_stats_caller',
     'annotation',
     'ariba_caller',
     'bacteriophage',
-    'blast_parser',
     'BUSCO_caller',
     'card_trick_caller',
     'database_generator',
